==> jooq-3.6.2-sources.jar: org/jooq/ArrayAggOrderByStep.java <==
/**
 * Copyright (c) 2009-2015, Data Geekery GmbH (http://www.datageekery.com)
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq;

import static org.jooq.SQLDialect.HSQLDB;
import static org.jooq.SQLDialect.POSTGRES;

import java.util.Collection;

import org.jooq.impl.DSL;

/**
 * The SQL standard <code>ARRAY_AGG()</code> function.
 *
 * @author Lukas Eder
 * @see DSL#arrayAgg(Field)
 */
public interface ArrayAggOrderByStep<T> extends AggregateFilterStep<T> {

    /**
     * Add an <code>ORDER BY</code> clause to the function.
     */
    @Support({ HSQLDB, POSTGRES })
    AggregateFilterStep<T> orderBy(Field<?>... fields);

    /**
     * Add an <code>ORDER BY</code> clause to the function.
     */
    @Support({ HSQLDB, POSTGRES })
    AggregateFilterStep<T> orderBy(SortField<?>... fields);

    /**
     * Add an <code>ORDER BY</code> clause to the function.
     */
    @Support({ HSQLDB, POSTGRES })
    AggregateFilterStep<T> orderBy(Collection<? extends SortField<?>> fields);
}

==> jooq-3.11.9-sources.jar: org/jooq/ArrayAggOrderByStep.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: http://www.jooq.org/licenses
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq;

// ...
import static org.jooq.SQLDialect.HSQLDB;
// ...
import static org.jooq.SQLDialect.POSTGRES;

import java.util.Collection;

import org.jooq.impl.DSL;

/**
 * The SQL standard <code>ARRAY_AGG()</code> function.
 *
 * @author Lukas Eder
 * @see DSL#arrayAgg(Field)
 */
public interface ArrayAggOrderByStep<T> extends AggregateFilterStep<T> {

    /**
     * Add an <code>ORDER BY</code> clause to the function.
     */
    @Support({ HSQLDB, POSTGRES })
    AggregateFilterStep<T> orderBy(OrderField<?>... fields);

    /**
     * Add an <code>ORDER BY</code> clause to the function.
     */
    @Support({ HSQLDB, POSTGRES })
    AggregateFilterStep<T> orderBy(Collection<? extends OrderField<?>> fields);
}
